import 'option.dart';
import 'terminal.dart';

final Terminal _terminal = const Terminal();

class Prompter {
  Map<String, dynamic> results = {};

  void _askText(String key, String prompt) {
    _terminal.printPrompt(prompt);
    _terminal.printOptions([]);
    String response = _terminal.collectInput();
    results[key] = response;
  }

  void _askBinary(String key, String prompt) {
    _terminal.printPrompt('$prompt (y/n)');
    _terminal.printOptions([]);
    String response = _terminal.collectInput();

    if(response == 'y') {
      results[key] = true;
    } else if(response == 'n') {
      results[key] = false;
    } else {
      _terminal.printError('Please enter y or n');
      _askBinary(key, prompt);
    }
  }

  void _askMultiple(String key, String prompt, List<Option> options) {
    _terminal.printPrompt(prompt);
    _terminal.printOptions(options);
    
    try {
      int response = int.parse(_terminal.collectInput());
      results[key] = options[response].value;
    } catch (e) {
      _terminal.printError('Please Enter a Number Within the Range of 0 - ${options.length - 1}');
      _askMultiple(key, prompt, options);
    }
  }

  void ask(String key, String prompt, String type, dynamic options) {
    _terminal.clearScreen();
    if(type == 'multiple') {
      _askMultiple(key, prompt, options);
    } else if(type == 'binary') {
      _askBinary(key, prompt);
    } else if(type == 'text') {
      _askText(key, prompt);
    } else {
      _terminal.printPrompt('$prompt has Invalid Prompt Type\n\n\n');
    }
  }
}
